//-----------------------------------------------------------------------------
//           Name: bitmap_fonts.inc
//         Author: John Fay
//  Last Modified: 01/26/05
//    Description: Data and utility functions for rendering bitmap based fonts. 
//                 This is a modified version of the bitmap based rendering 
//                 system from the open source Freeglut project.
//                 http://freeglut.sourceforge.net/
//-----------------------------------------------------------------------------

#ifndef _BITMAP_FONTS_INC_
#define _BITMAP_FONTS_INC_


//#use "glFonts.lib"

/*
 * The bitmap font structure
 */
#typedef GLubyte unsigned byte

struct BitmapFontData
{
    string   *Name;         /* The source font name             */
    int       Quantity;     /* Number of chars in font          */
    int       Height;       /* Height of the characters         */
    GLubyte  *Characters;   /* The characters mapping           */

    float     xorig; /* Relative origin of the character */
	float     yorig;
};

/*
 * Following fonts are defined in this file:
 * 
 * 1. FontFixed8x13 <-misc-fixed-medium-r-normal--13-120-75-75-C-80-iso8859-1>
 * 2. FontFixed9x15 <-misc-fixed-medium-r-normal--15-140-75-75-C-90-iso8859-1>
 * 3. FontHelvetica10 <-adobe-helvetica-medium-r-normal--10-100-75-75-p-56-iso8859-1>
 * 4. FontHelvetica12 <-adobe-helvetica-medium-r-normal--12-120-75-75-p-67-iso8859-1>
 * 5. FontHelvetica18 <-adobe-helvetica-medium-r-normal--18-180-75-75-p-98-iso8859-1>
 * 6. FontTimesRoman10 <-adobe-times-medium-r-normal--10-100-75-75-p-54-iso8859-1>
 * 7. FontTimesRoman24 <-adobe-times-medium-r-normal--24-240-75-75-p-124-iso8859-1>
 */

extern FontFixed8x13 as BitmapFontData;
extern FontFixed9x15 as BitmapFontData;
extern FontHelvetica10 as BitmapFontData;
extern FontHelvetica12 as BitmapFontData;
extern FontHelvetica18 as BitmapFontData;
extern FontTimesRoman10 as BitmapFontData;
extern FontTimesRoman24 as BitmapFontData;


enum BitmapFontType
{
	BITMAP_FONT_TYPE_8_BY_13 = 0,
	BITMAP_FONT_TYPE_9_BY_15,
	BITMAP_FONT_TYPE_HELVETICA_10,
	BITMAP_FONT_TYPE_HELVETICA_12,
	BITMAP_FONT_TYPE_HELVETICA_18,
	BITMAP_FONT_TYPE_TIMES_ROMAN_10,
	BITMAP_FONT_TYPE_TIMES_ROMAN_24
}

//-----------------------------------------------------------------------------
// Name: getBitmapFontDataByType()
// Desc: Matches a BitmapFontType with a BitmapFontData structure pointer.
//-----------------------------------------------------------------------------
declare extern getBitmapFontDataByType( BitmapFontType font ),BitmapFontData *;

//-----------------------------------------------------------------------------
// Name: beginRenderText()
// Desc: Utility function for using the bitmap-based character fonts defined 
//       above. Call this function to begin rendering text. Call the function 
//       endRenderText to stop.
//-----------------------------------------------------------------------------
declare extern beginRenderText( int nWindowWidth, int nWindowHeight );


//-----------------------------------------------------------------------------
// Name: endRenderText()
// Desc: Utility function for using the bitmap-based character fonts defined 
//       above. Call this function to stop rendering text. The call to 
//       beginRenderText should come first and be paired with this function.
//-----------------------------------------------------------------------------
declare extern endRenderText(  );


/*-----------------------------------------------------------------------------
// Name: renderText()
// Desc: Utility function for using the bitmap-based character fonts defined 
//       above. This function must be called in between a call to 
//       beginRenderText and endRenderText. See the example below:
//
//       beginRenderText( nWindowWidth, nWindowHeight );
//       {
//           renderText( 5, 10, "This is a test!", BITMAP_FONT_TYPE_HELVETICA_12 );
//       }
//       endRenderText();
//
//-----------------------------------------------------------------------------*/
declare extern renderText( float x, float y, BitmapFontType fontType, string *pstring );


#endif
